@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::MSCHOUT;
-$Dist::Zilla::PluginBundle::MSCHOUT::VERSION = '0.29';
+$Dist::Zilla::PluginBundle::MSCHOUT::VERSION = '0.30';
 # ABSTRACT: Use L<Dist::Zilla> like MSCHOUT does
 
 use Moose;
@@ -49,6 +49,7 @@ sub configure {
             Bugtracker
             Homepage
             Signature
+            MetaJSON
             ArchiveRelease
         ),
         # update release in Changes file
@@ -94,7 +95,7 @@ sub configure {
         [ RemovePrereqs => { remove => 'Module::Signature' } ]
     );
 
-    if ($$args{use_twitter}) {
+    if ($$args{use_twitter} and $upload) {
         $self->add_plugins(
             [ Twitter => { hash_tags => '#perl' } ]
         );
@@ -115,7 +116,7 @@ Dist::Zilla::PluginBundle::MSCHOUT - Use L<Dist::Zilla> like MSCHOUT does
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 DESCRIPTION
 
@@ -139,6 +140,7 @@ It's equivalent to:
  [Bugtracker]
  [Homepage]
  [Signature]
+ [MetaJSON]
  [ArchiveRelease]
  [NextRelease]
     format = "%-2v  %{yyyy-MM-dd}d"
@@ -177,6 +179,19 @@ task
 Replaces C<Pod::Weaver> with C<Task::Weaver> and uses C<AutoVersion> instead of
 C<Git::NextVersion>
 
+=item *
+
+use_travis
+
+Enables the L<TravisYML|Dist::Zilla::Plugin::TravisYML> Dist Zilla plugin.
+
+=item *
+
+use_twitter
+
+Enables the L<Twitter|Dist::Zilla::Plugin::Twitter> Dist Zilla plugin.  If
+C<no_upload> is set, this plugin is skipped.
+
 =back
 
 =for Pod::Coverage configure
